@@ -76,7 +76,7 @@
 #'              tol = c(-Inf, 1e-10, Inf))
 #'
 #' # One can check for whole numbers like so
-#' whole_number <- function(x, tol = getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps))){
+#' whole_number <- function(x, tol = get_tolerance()){
 #'   double_equal(x, round(x))
 #' }
 #' whole_number(seq(-5, 5, 0.25))
@@ -88,7 +88,7 @@
   } else {
     cpp_double_equal(
       as.double(x), as.double(y),
-      as.double(getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps)))
+      as.double(get_tolerance())
     )
   }
 }
@@ -100,7 +100,7 @@
   } else {
     cpp_double_gte(
       as.double(x), as.double(y),
-      as.double(getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps)))
+      as.double(get_tolerance())
     )
   }
 }
@@ -112,7 +112,7 @@
   } else {
     cpp_double_gt(
       as.double(x), as.double(y),
-      as.double(getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps)))
+      as.double(get_tolerance())
     )
   }
 }
@@ -124,7 +124,7 @@
   } else {
     cpp_double_lte(
       as.double(x), as.double(y),
-      as.double(getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps)))
+      as.double(get_tolerance())
     )
   }
 }
@@ -136,13 +136,13 @@
   } else {
     cpp_double_lt(
       as.double(x), as.double(y),
-      as.double(getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps)))
+      as.double(get_tolerance())
     )
   }
 }
 #' @rdname doubles
 #' @export
-double_equal <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps))){
+double_equal <- function(x, y, tol = get_tolerance()){
   if (is.integer(x) && is.integer(y)){
     x == y
   } else {
@@ -151,7 +151,7 @@ double_equal <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Mac
 }
 #' @rdname doubles
 #' @export
-double_gte <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps))){
+double_gte <- function(x, y, tol = get_tolerance()){
   if (is.integer(x) && is.integer(y)){
     x >= y
   } else {
@@ -160,7 +160,7 @@ double_gte <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machi
 }
 #' @rdname doubles
 #' @export
-double_gt <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps))){
+double_gt <- function(x, y, tol = get_tolerance()){
   if (is.integer(x) && is.integer(y)){
     x > y
   } else {
@@ -169,7 +169,7 @@ double_gt <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machin
 }
 #' @rdname doubles
 #' @export
-double_lte <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps))){
+double_lte <- function(x, y, tol = get_tolerance()){
   if (is.integer(x) && is.integer(y)){
     x <= y
   } else {
@@ -178,11 +178,10 @@ double_lte <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machi
 }
 #' @rdname doubles
 #' @export
-double_lt <- function(x, y, tol = getOption("cppdoubles.tolerance", sqrt(.Machine$double.eps))){
+double_lt <- function(x, y, tol = get_tolerance()){
   if (is.integer(x) && is.integer(y)){
     x < y
   } else {
     cpp_double_lt(as.double(x), as.double(y), as.double(tol))
   }
 }
-
